**Example 1: 找回站点**



Input: 

```
tccli teo ReclaimZone --cli-unfold-argument  \
    --ZoneName example.com
```

Output: 
```
{
    "Response": {
        "RequestId": "3ds50b24-5dv3-4sf4-96ce-61825d53ff5d"
    }
}
```

